# History Matching (Core)
Core package for Bayesian History Matching. Generic as possible implementation built upon scikit-learn Gaussian Process Regression layer for the emulation. 

Implements helper functions and classes for conducting history matching runs, handling different sampling spaces. 

Developed by Robert King (robcking@stanford.edu)
